@@ -8,10 +8,13 @@ from sqlalchemy_continuum import (
 
 
 class TestCase(object):
+    inspect_column_order = False
+
     def setup_method(self, method):
         self.engine = create_engine(
             'postgres://postgres@localhost/sqlalchemy_versioned_test'
         )
+        self.connection = self.engine.connect()
         #self.engine.echo = True
         self.Model = declarative_base()
 
@@ -22,23 +25,32 @@ class TestCase(object):
         )
 
         sa.orm.configure_mappers()
-        self.ArticleHistory = self.Article.__versioned__['class']
-        self.Model.metadata.create_all(self.engine)
+        if hasattr(self, 'Article'):
+            self.ArticleHistory = self.Article.__versioned__['class']
+        self.create_tables()
 
-        Session = sessionmaker(bind=self.engine)
+        Session = sessionmaker(bind=self.connection)
         versioned_session(Session)
         self.session = Session()
 
+    def create_tables(self):
+        self.Model.metadata.create_all(self.connection)
+
+    def drop_tables(self):
+        self.Model.metadata.drop_all(self.connection)
+
     def teardown_method(self, method):
         self.session.close_all()
-        self.Model.metadata.drop_all(self.engine)
+        self.drop_tables()
         self.engine.dispose()
+        self.connection.close()
 
     def create_models(self):
         class Article(self.Model, Versioned):
             __tablename__ = 'article'
             __versioned__ = {
-                'base_classes': (self.Model, )
+                'base_classes': (self.Model, ),
+                'inspect_column_order': self.inspect_column_order
             }
 
             id = sa.Column(sa.Integer, autoincrement=True, primary_key=True)
@@ -49,7 +61,8 @@ class TestCase(object):
         class Tag(self.Model, Versioned):
             __tablename__ = 'tag'
             __versioned__ = {
-                'base_classes': (self.Model, )
+                'base_classes': (self.Model, ),
+                'inspect_column_order': self.inspect_column_order
             }
 
             id = sa.Column(sa.Integer, autoincrement=True, primary_key=True)
